@@ -663,7 +663,7 @@ if ($builder eq "none") {
     # this simply forces dpkg-buildpackage to run without fakeroot.
     push @cmd,
         "--starting-build-commands="
-      . 'grep -q "^Rules-Requires-Root: " "%p/debian/control" || '
+      . 'grep -iq "^Rules-Requires-Root:" "%p/debian/control" || '
       . 'sed -i "1iRules-Requires-Root: no" "%p/debian/control"';
     # without --verbose, the log will be suppressed by default if sbuild is
     # not run on an interactive tty, so we make sure the behaviour is always
